SAENOPY
=======

[![DOC](https://readthedocs.org/projects/saenopy/badge/)](https://saenopy.readthedocs.io)
[![DOC](https://api.travis-ci.com/rgerum/saenopy.svg?branch=master)](https://travis-ci.com/github/rgerum/saenopy)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

<p align="center">
  <img src="saenopy/img/Logo.png" />
</p>



SAENOPY a python implementation of the SAENO - Semi-affine Elastic Network Optimizer, originally developed by Julian
 Steinwachs.

[Documentation](https://saenopy.readthedocs.io)
